==> yylib-quick-mobile-0.0.45.tgz: package/source/yylib/date-picker/YYDatePicker.js <==
'use strict';

var _datePicker = require('antd-mobile/lib/date-picker');

var _datePicker2 = _interopRequireDefault(_datePicker);

var _list = require('antd-mobile/lib/list');

var _list2 = _interopRequireDefault(_list);

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

require('antd-mobile/lib/date-picker/style/css');

require('antd-mobile/lib/list/style/css');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _YYIcon = require('../icon/YYIcon');

var _YYIcon2 = _interopRequireDefault(_YYIcon);

var _FunctionUtil = require('../../utils/FunctionUtil');

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

require('./YYDatePicker.less');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Item = _list2.default.Item;


var nowTimeStamp = Date.now();
var now = new Date(nowTimeStamp);
var utcOffset = new Date(now.getTime() - now.getTimezoneOffset() * 60000);

var YYDatePicker = function (_Component) {
    _inherits(YYDatePicker, _Component);

    function YYDatePicker() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, YYDatePicker);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = YYDatePicker.__proto__ || Object.getPrototypeOf(YYDatePicker)).call.apply(_ref, [this].concat(args))), _this), _this._clearDate = function () {
            var fields = {};
            fields[_this.props.field] = {
                dirty: true,
                errors: undefined,
                name: _this.props.field,
                touched: true,
                validating: true,
                value: null
            };
            _this.props.form.setFields(fields);
        }, _this.onValueChange = function (vals, index) {
            if ((0, _FunctionUtil.isFunction)(_this.props.onValueChange)) _this.props.onValueChange(vals, index);
        }, _this.onChange = function (date) {
            var fields = {};
            fields[_this.props.field] = {
                dirty: true,
                errors: undefined,
                name: _this.props.field,
                touched: true,
                validating: true,
                value: date
            };
            _this.props.form.setFields(fields);
            if ((0, _FunctionUtil.isFunction)(_this.props.onChange)) _this.props.onChange(date);
        }, _this.onDismiss = function () {
            if ((0, _FunctionUtil.isFunction)(_this.props.onDismiss)) _this.props.onDismiss();
        }, _this.onOk = function (val) {
            if ((0, _FunctionUtil.isFunction)(_this.props.onOk)) _this.props.onOk(val);
        }, _this.validateCallBack = function (rule, value, callback) {
            if ((0, _FunctionUtil.isFunction)(_this.props.validateCallBack)) {
                _this.props.validateCallBack(rule, value, callback);
                callback();
            } else {
                callback();
            }
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(YYDatePicker, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextprops) {
            if (nextprops.value !== this.props.value) {
                var dateValue = new Date(nextprops.value);
                var fields = {};
                fields[this.props.field] = {
                    dirty: true,
                    errors: undefined,
                    name: this.props.field,
                    touched: true,
                    validating: true,
                    value: dateValue
                };
                this.props.form.setFields(fields);
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var getFieldProps = this.props.form.getFieldProps;

            var _props = this.props,
                mode = _props.mode,
                value = _props.value,
                use12Hours = _props.use12Hours,
                minuteStep = _props.minuteStep,
                disabled = _props.disabled,
                minDate = _props.minDate,
                maxDate = _props.maxDate,
                wrap = _props.wrap,
                label = _props.label,
                arrow = _props.arrow,
                extra = _props.extra,
                field = _props.field,
                required = _props.required,
                trigger = _props.trigger,
                showIcon = _props.showIcon,
                icon = _props.icon,
                iconColor = _props.iconColor,
                visible = _props.visible,
                restProps = _objectWithoutProperties(_props, ['mode', 'value', 'use12Hours', 'minuteStep', 'disabled', 'minDate', 'maxDate', 'wrap', 'label', 'arrow', 'extra', 'field', 'required', 'trigger', 'showIcon', 'icon', 'iconColor', 'visible']);

            var wrapClz = (0, _classnames2.default)('yy-date-picker', this.props.className);
            var itemWrapClz = (0, _classnames2.default)('yy-date-picker-item', !visible && 'hidden', this.props.className);
            var requiredMsg = '必填项' + label + '未填写';
            value = value ? value.replace(/\-/g, '/') : null;
            var _fieldValue = (0, _FunctionUtil.isFunction)(getFieldProps) ? getFieldProps(field, {
                initialValue: typeof value === 'string' ? new Date(value) : value,
                rules: [{ required: required, message: requiredMsg }, { validator: this.validateCallBack }],
                trigger: trigger,
                valuePropName: 'value'
            }) : null;
            if (_fieldValue.value && typeof _fieldValue.value === 'string') {
                _fieldValue.value = new Date(_fieldValue.value);
            }
            return _react2.default.createElement(
                _datePicker2.default,
                _extends({}, restProps, {
                    className: wrapClz
                }, _fieldValue, {
                    mode: mode,
                    minDate: typeof minDate === 'string' ? new Date(minDate) : minDate,
                    maxDate: typeof maxDate === 'string' ? new Date(maxDate) : maxDate,
                    use12Hours: use12Hours,
                    minuteStep: minuteStep,
                    disabled: disabled,
                    extra: disabled ? " " : extra,
                    title: _react2.default.createElement(
                        'a',
                        { style: { color: '#108ee9' }, onClick: this._clearDate },
                        '\u6E05\u9664'
                    ),
                    onValueChange: this.onValueChange,
                    onChange: this.onChange,
                    onDismiss: this.onDismiss,
                    onOk: this.onOk
                }),
                _react2.default.createElement(
                    _list2.default.Item,
                    { className: itemWrapClz, arrow: disabled ? "empty" : arrow, wrap: wrap },
                    showIcon && _react2.default.createElement(_YYIcon2.default, { type: icon, color: iconColor, style: { float: 'left', paddingRight: '8px' }, size: 'xs' }),
                    required ? _react2.default.createElement(
                        'span',
                        { className: 'yy-label-required' },
                        label
                    ) : label
                )
            );
        }
    }]);

    return YYDatePicker;
}(_react.Component);

;

YYDatePicker.defaultProps = {
    mode: 'date',
    value: null,
    use12Hours: false,
    minuteStep: 1,
    disabled: false,
    label: '日期',
    extra: '请选择',
    arrow: 'horizontal',
    wrap: false,
    field: 'datepicker',
    required: false,
    trigger: 'onChange',
    showIcon: false,
    icon: "Home",
    iconColor: "red",
    visible: true
};

module.exports = YYDatePicker;

==> yylib-quick-mobile-0.0.57.tgz: package/source/yylib/date-picker/YYDatePicker.js <==
'use strict';

var _datePicker = require('antd-mobile/lib/date-picker');

var _datePicker2 = _interopRequireDefault(_datePicker);

var _list = require('antd-mobile/lib/list');

var _list2 = _interopRequireDefault(_list);

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

require('antd-mobile/lib/date-picker/style/css');

require('antd-mobile/lib/list/style/css');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _YYIcon = require('../icon/YYIcon');

var _YYIcon2 = _interopRequireDefault(_YYIcon);

var _FunctionUtil = require('../../utils/FunctionUtil');

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

require('./YYDatePicker.less');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Item = _list2.default.Item;


var nowTimeStamp = Date.now();
var now = new Date(nowTimeStamp);
var utcOffset = new Date(now.getTime() - now.getTimezoneOffset() * 60000);

var YYDatePicker = function (_Component) {
    _inherits(YYDatePicker, _Component);

    function YYDatePicker() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, YYDatePicker);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = YYDatePicker.__proto__ || Object.getPrototypeOf(YYDatePicker)).call.apply(_ref, [this].concat(args))), _this), _this._clearDate = function () {
            var fields = {};
            fields[_this.props.field] = {
                dirty: true,
                errors: undefined,
                name: _this.props.field,
                touched: true,
                validating: true,
                value: null
            };
            _this.props.form.setFields(fields);
        }, _this.onValueChange = function (vals, index) {
            if ((0, _FunctionUtil.isFunction)(_this.props.onValueChange)) _this.props.onValueChange(vals, index);
        }, _this.onChange = function (date) {
            var fields = {};
            fields[_this.props.field] = {
                dirty: true,
                errors: undefined,
                name: _this.props.field,
                touched: true,
                validating: true,
                value: date
            };
            _this.props.form.setFields(fields);
            if ((0, _FunctionUtil.isFunction)(_this.props.onChange)) _this.props.onChange(date);
        }, _this.onDismiss = function () {
            if ((0, _FunctionUtil.isFunction)(_this.props.onDismiss)) _this.props.onDismiss();
        }, _this.onOk = function (val) {
            if ((0, _FunctionUtil.isFunction)(_this.props.onOk)) _this.props.onOk(val);
        }, _this.validateCallBack = function (rule, value, callback) {
            if ((0, _FunctionUtil.isFunction)(_this.props.validateCallBack)) {
                _this.props.validateCallBack(rule, value, callback);
                callback();
            } else {
                callback();
            }
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(YYDatePicker, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextprops) {
            if (nextprops.value !== this.props.value) {
                var dateValue = new Date(nextprops.value);
                var fields = {};
                fields[this.props.field] = {
                    dirty: true,
                    errors: undefined,
                    name: this.props.field,
                    touched: true,
                    validating: true,
                    value: dateValue
                };
                this.props.form.setFields(fields);
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var getFieldProps = this.props.form.getFieldProps;

            var _props = this.props,
                mode = _props.mode,
                value = _props.value,
                use12Hours = _props.use12Hours,
                minuteStep = _props.minuteStep,
                disabled = _props.disabled,
                minDate = _props.minDate,
                maxDate = _props.maxDate,
                wrap = _props.wrap,
                label = _props.label,
                arrow = _props.arrow,
                extra = _props.extra,
                field = _props.field,
                required = _props.required,
                trigger = _props.trigger,
                showIcon = _props.showIcon,
                icon = _props.icon,
                iconColor = _props.iconColor,
                visible = _props.visible,
                restProps = _objectWithoutProperties(_props, ['mode', 'value', 'use12Hours', 'minuteStep', 'disabled', 'minDate', 'maxDate', 'wrap', 'label', 'arrow', 'extra', 'field', 'required', 'trigger', 'showIcon', 'icon', 'iconColor', 'visible']);

            var wrapClz = (0, _classnames2.default)('yy-date-picker', this.props.className);
            var itemWrapClz = (0, _classnames2.default)('yy-date-picker-item', !visible && 'hidden', this.props.className);
            var requiredMsg = '必填项' + label + '未填写';
            value = value ? value.replace(/\-/g, '/') : null;
            var _fieldValue = (0, _FunctionUtil.isFunction)(getFieldProps) ? getFieldProps(field, {
                initialValue: typeof value === 'string' ? new Date(value) : value,
                rules: [{ required: required, message: requiredMsg }, { validator: this.validateCallBack }],
                trigger: trigger,
                valuePropName: 'value'
            }) : null;
            if (_fieldValue.value && typeof _fieldValue.value === 'string') {
                _fieldValue.value = new Date(_fieldValue.value);
            }
            return _react2.default.createElement(
                _datePicker2.default,
                _extends({}, restProps, {
                    className: wrapClz
                }, _fieldValue, {
                    mode: mode,
                    minDate: typeof minDate === 'string' ? new Date(minDate) : minDate,
                    maxDate: typeof maxDate === 'string' ? new Date(maxDate) : maxDate,
                    use12Hours: use12Hours,
                    minuteStep: minuteStep,
                    disabled: disabled,
                    extra: disabled ? " " : extra,
                    title: _react2.default.createElement(
                        'a',
                        { style: { color: '#108ee9' }, onClick: this._clearDate },
                        '\u6E05\u9664'
                    ),
                    onValueChange: this.onValueChange,
                    onChange: this.onChange,
                    onDismiss: this.onDismiss,
                    onOk: this.onOk
                }),
                _react2.default.createElement(
                    _list2.default.Item,
                    { className: itemWrapClz, arrow: disabled ? null : arrow, wrap: wrap },
                    showIcon && _react2.default.createElement(_YYIcon2.default, { type: icon, color: iconColor, style: { float: 'left', paddingRight: '8px' }, size: 'xs' }),
                    required ? _react2.default.createElement(
                        'span',
                        { className: 'yy-label-required' },
                        label
                    ) : label
                )
            );
        }
    }]);

    return YYDatePicker;
}(_react.Component);

;

YYDatePicker.defaultProps = {
    mode: 'date',
    value: null,
    use12Hours: false,
    minuteStep: 1,
    disabled: false,
    label: '日期',
    extra: '请选择',
    arrow: 'horizontal',
    wrap: false,
    field: 'datepicker',
    required: false,
    trigger: 'onChange',
    showIcon: false,
    icon: "Home",
    iconColor: "red",
    visible: true
};

module.exports = YYDatePicker;
